@@ -82,8 +82,8 @@ class MultiSelectBox(Component):
             tag.select(**attr)(self._get_select_options(field, ticket)))
 
     def _get_field_values(self, ticket, field):
-        values = ticket.values.get(field, '')
-        return [] if values is None else values.split()
+        values = ticket.values.get(field, None)
+        return [] if values is None else values.replace(',', ' ').split()
 
     def _get_multi_select_fields(self):
         conf = self.config['ticket-custom']
